@@ -58,7 +58,7 @@ KgpgTrustLabel::KgpgTrustLabel(QWidget *parent)
 
     QHBoxLayout *layout = new QHBoxLayout(this);
     layout->setSpacing(10);
-    layout->setMargin(2);
+    layout->setContentsMargins(2, 2, 2, 2);
     layout->addWidget(m_text_w);
     layout->addWidget(m_color_w);
 
@@ -144,9 +144,9 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
 
-    connect(m_owtrust, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &KgpgKeyInfo::slotChangeTrust);
-    connect(m_photoid, static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::activated), this, &KgpgKeyInfo::slotLoadPhoto);
-    connect(m_email, static_cast<void (KUrlLabel::*)(const QString &)>(&KUrlLabel::leftClickedUrl), this, &KgpgKeyInfo::slotOpenUrl);
+    connect(m_owtrust, QOverload<int>::of(&QComboBox::activated), this, &KgpgKeyInfo::slotChangeTrust);
+    connect(m_photoid, QOverload<const QString &>::of(&QComboBox::activated), this, &KgpgKeyInfo::slotLoadPhoto);
+    connect(m_email, QOverload<const QString &>::of(&KUrlLabel::leftClickedUrl), this, &KgpgKeyInfo::slotOpenUrl);
     connect(keychange, &KGpgChangeKey::done, this, &KgpgKeyInfo::slotApplied);
     connect(m_disable, &QCheckBox::toggled, this, &KgpgKeyInfo::slotDisableKey);
     connect(m_expirationbtn, &QPushButton::clicked, this, &KgpgKeyInfo::slotChangeDate);
@@ -211,7 +211,7 @@ void KgpgKeyInfo::displayKey()
     if (key->valid()) {
         QModelIndex idx = m_model->nodeIndex(m_node, KEYCOLUMN_TRUST);
         trust = m_model->data(idx, Qt::AccessibleTextRole).toString();
-        trustcolor = m_model->data(idx, Qt::BackgroundColorRole).value<QColor>();
+        trustcolor = m_model->data(idx, Qt::BackgroundRole).value<QColor>();
     } else {
         trust = Convert::toString(TRUST_DISABLED);
         trustcolor = KGpgSettings::colorBad();
