@@ -25,10 +25,10 @@ class newKey : public QWidget, public Ui_newKey
     Q_OBJECT
 
 public:
-    explicit newKey(QWidget* parent = Q_NULLPTR);
+    explicit newKey(QWidget* parent = nullptr);
 
 
-public slots:
+public Q_SLOTS:
    void CBsave_toggled(bool);
 };
 
